@@ -1,4 +1,3 @@
-import sys
 from .urllib3 import Urllib3Interceptor
 from .http import HTTPClientInterceptor
 from .base import BaseInterceptor
@@ -18,14 +17,12 @@ interceptors = [
     HTTPClientInterceptor
 ]
 
-# Import aiohttp in modern Python runtimes
-if sys.version_info >= (3, 5, 0):
-    try:
-        import aiohttp # noqa
-        from .aiohttp import AIOHTTPInterceptor
-        interceptors.append(AIOHTTPInterceptor)
-    except ImportError:
-        pass
+try:
+    import aiohttp # noqa
+    from .aiohttp import AIOHTTPInterceptor
+    interceptors.append(AIOHTTPInterceptor)
+except ImportError:
+    pass
 
 
 def add(*custom_interceptors):
